==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/villager/FumoSellerVillager.java <==
package cc.thonly.reverie_dreams.entity.villager;

import cc.thonly.reverie_dreams.entity.ModEntities;
import cc.thonly.reverie_dreams.fumo.Fumo;
import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;
import cc.thonly.reverie_dreams.registry.RegistryManager;
import net.minecraft.class_1299;
import net.minecraft.class_1646;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1914;
import net.minecraft.class_1937;
import net.minecraft.class_2378;
import net.minecraft.class_3850;
import net.minecraft.class_3852;
import net.minecraft.class_3854;
import net.minecraft.class_3989;
import net.minecraft.class_5455;
import net.minecraft.class_7924;
import net.minecraft.class_9306;
import net.minecraft.server.MinecraftServer;
import net.minecraft.village.*;
import java.util.*;


public class FumoSellerVillager extends AbstractSellerEntity {

    public FumoSellerVillager(class_1299<? extends class_3989> entityType, class_1937 world) {
        super(entityType, world);
    }

    public FumoSellerVillager(class_1937 world) {
        super(ModEntities.FUMO_SELLER_VILLAGER, world);
    }

    public FumoSellerVillager(class_3850 prev, class_1937 world) {
        super(ModEntities.FUMO_SELLER_VILLAGER, world);
        this.prev = prev;
    }

    public FumoSellerVillager(class_1646 prevEntity, class_1937 world) {
        super(ModEntities.FUMO_SELLER_VILLAGER, world);
        this.prev = prevEntity.method_7231();
    }

    public List<class_1914> getVillagerOffers() {
        long seed = this.getVillagerSeed();
        Random random = new Random(seed);

        List<class_1914> offers = new ArrayList<>();
        List<Fumo> allFumos = new ArrayList<>(RegistryManager.FUMO.values());

        Collections.shuffle(allFumos, random);

        int count = 4 + random.nextInt(5) + this.level;
        List<Fumo> selectedFumos = allFumos.subList(0, Math.min(count, allFumos.size()));

        for (Fumo fumo : selectedFumos) {
            class_1792 item = fumo.item();
            class_1799 sellItem = new class_1799(item);
            ItemStackWrapper wrapper = ItemStackWrapper.of(sellItem);

            int emeraldAmount = 31 + random.nextInt(14);
            class_9306 first = new class_9306(class_1802.field_8687, emeraldAmount);
            class_9306 second = new class_9306(class_1802.field_19044, 32);

            class_1914 offer = new class_1914(first, Optional.of(second), sellItem, Math.max(0, 2 - this.sellInfo.getSellArchive(seed, wrapper)), 1, 0.05f);
            offers.add(offer);
        }

        return offers;
    }

    @Override
    public class_3850 getModifyVillagerData(MinecraftServer server) {
        class_5455.class_6890 registryManager = server.method_30611();
        class_2378<class_3854> villagerTypeRegistry = registryManager.method_30530(class_7924.field_41235);
        class_2378<class_3852> villagerProfessionRegistry = registryManager.method_30530(class_7924.field_41234);

        return new class_3850(
                villagerTypeRegistry.method_46747(class_3854.field_17073),
                villagerProfessionRegistry.method_46747(class_3852.field_17060),
                2
        );
    }

    @Override
    public boolean canReset() {
        return true;
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/villager/FumoSellerVillager.java <==
package cc.thonly.reverie_dreams.entity.villager;

import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import cc.thonly.reverie_dreams.data.FumoType;
import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;
import cc.thonly.reverie_dreams.registry.RegistryHandlers;
import net.minecraft.class_1299;
import net.minecraft.class_1646;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1914;
import net.minecraft.class_1937;
import net.minecraft.class_2378;
import net.minecraft.class_3850;
import net.minecraft.class_3852;
import net.minecraft.class_3854;
import net.minecraft.class_3989;
import net.minecraft.class_5455;
import net.minecraft.class_7924;
import net.minecraft.class_9306;
import net.minecraft.server.MinecraftServer;
import java.util.*;


public class FumoSellerVillager extends AbstractSellerEntity {

    public FumoSellerVillager(class_1299<? extends class_3989> entityType, class_1937 world) {
        super(entityType, world);
    }

    public FumoSellerVillager(class_1937 world) {
        super(RDEntityTypes.FUMO_SELLER_VILLAGER, world);
    }

    public FumoSellerVillager(class_3850 prev, class_1937 world) {
        super(RDEntityTypes.FUMO_SELLER_VILLAGER, world);
        this.prev = prev;
    }

    public FumoSellerVillager(class_1646 prevEntity, class_1937 world) {
        super(RDEntityTypes.FUMO_SELLER_VILLAGER, world);
        this.prev = prevEntity.method_7231();
    }

    public List<class_1914> getVillagerOffers() {
        long seed = this.getVillagerSeed();
        Random random = new Random(seed);

        List<class_1914> offers = new ArrayList<>();
        List<FumoType> allFumos = new ArrayList<>(RegistryHandlers.FUMO.values());

        Collections.shuffle(allFumos, random);

        int count = 4 + random.nextInt(5) + this.level;
        List<FumoType> selectedFumos = allFumos.subList(0, Math.min(count, allFumos.size()));

        for (FumoType fumo : selectedFumos) {
            class_1792 item = fumo.item();
            class_1799 sellItem = new class_1799(item);
            ItemStackWrapper wrapper = ItemStackWrapper.of(sellItem);

            int emeraldAmount = 31 + random.nextInt(14);
            class_9306 first = new class_9306(class_1802.field_8687, emeraldAmount);
            class_9306 second = new class_9306(class_1802.field_19044, 32);

            class_1914 offer = new class_1914(first, Optional.of(second), sellItem, Math.max(0, 2 - this.sellInfo.getSellArchive(seed, wrapper)), 1, 0.05f);
            offers.add(offer);
        }

        return offers;
    }

    @Override
    public class_3850 getModifyVillagerData(MinecraftServer server) {
        class_5455.class_6890 registryManager = server.method_30611();
        class_2378<class_3854> villagerTypeRegistry = registryManager.method_30530(class_7924.field_41235);
        class_2378<class_3852> villagerProfessionRegistry = registryManager.method_30530(class_7924.field_41234);

        return new class_3850(
                villagerTypeRegistry.method_46747(class_3854.field_17073),
                villagerProfessionRegistry.method_46747(class_3852.field_17060),
                2
        );
    }

    @Override
    public boolean canReset() {
        return true;
    }
}
